@@ -17,13 +17,10 @@ impl Channels {
      *
      * Stop watching resources through this channel
      */
-    pub async fn drive_stop(&self, body: &crate::types::Channel) -> Result<()> {
+    pub async fn stop(&self, body: &crate::types::Channel) -> Result<()> {
         let url = "/channels/stop".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
